componenttools.get_components_in_expr_with_name
===============================================

.. autofunction:: abjad.tools.componenttools.get_components_in_expr_with_name.get_components_in_expr_with_name
   :noindex:
